var iniparser = require('iniparser');
var config = iniparser.parseSync('./config.ini');
var whiskers = require('whiskers');

var numeral = require('numeral');
numeral.language('id', {
    delimiters: {
        thousands: '.',
        decimal: ','
    },
    abbreviations: {
        thousand: 'k',
        million: 'm',
        billion: 'b',
        trillion: 't'
    },
    ordinal : function (number) {
        return number === 1 ? 'er' : 'ème';
    },
    currency: {
        symbol: 'Rp.'
    }
});
numeral.language('id');

var Sync = require('sync');
var redis = require('redis').createClient(config.globals.redis_port, config.globals.redis_host);

var express = require('express');
var app = express();

var suppliers = config.globals.suppliers.split(',');

if (!config.expresso_urls) {
    config.expresso_urls = {};
}

app.engine('.html', whiskers.__express);
app.engine('.txt', whiskers.__express);
app.engine('.json', whiskers.__express);

app.set('views', __dirname+'/views');

function getBalances(suppliers, thousands, callback) {

    var kw = [];
    var count = suppliers.length;

    for (var i=0; i < count; i++) {
        var supplier = suppliers[i];
        kw.push('balance.gw:' + supplier);
    }

    redis.mget(kw, function(err, res) {
        var balances = [];

        for (var i=0; i<count; i++) {
            var value = res[i];
            if (!value) {
                value = 0;
            }

            if (thousands) {
                value = numeral(res[i]).format('0,0');
            }

            var url = null;
            var supplier = suppliers[i];

            if (config.expresso_urls[supplier]) {
                url = config.expresso_urls[supplier];
            }

            balances.push({
                title: supplier,
                balance: value,
                url: url,
            });
        }

        callback(null, balances);
    });
}

app.get('/', function(req, res) {

    Sync(function() {
        var template_file;
        var thousands = true;

        res.format({
            html: function() {
                template_file = 'index.html';
            },
            text: function() {
                template_file = 'index.txt';
            },
            json: function() {
                thousands = false;
                template_file = 'index.json';
            },
            'default': function() {
                template_file = 'index.html';
            },

        });

        var balances = getBalances.sync(null, suppliers, thousands);
        //balances = getBalances(suppliers);

        res.render(template_file, {
            _logo: 'https://imageshack.com/a/img922/2950/APPRuh.png',
            logo: 'https://imagizer.imageshack.us/a/img922/2950/APPRuh.png',
            title: 'Supplier Balances',
            balances: balances,
            json_string: JSON.stringify(balances),
            timestamp: new Date(),
        });
    })

});

var server = app.listen(config.globals.http_port, function () {
  var host = server.address().address;
  var port = server.address().port;

  console.log('Example app listening at http://%s:%s', host, port);
});
